@@ -409,7 +409,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
      */
     public function testFindByAssociationKey_ExceptionOnInverseSide()
     {
-        list($userId, $addressId) = $this->loadAssociatedFixture();
+        [$userId, $addressId] = $this->loadAssociatedFixture();
         $repos = $this->_em->getRepository(CmsUser::class);
 
         $this->expectException(ORMException::class);
@@ -423,7 +423,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
      */
     public function testFindOneByAssociationKey()
     {
-        list($userId, $addressId) = $this->loadAssociatedFixture();
+        [$userId, $addressId] = $this->loadAssociatedFixture();
         $repos = $this->_em->getRepository(CmsAddress::class);
         $address = $repos->findOneBy(['user' => $userId]);
 
@@ -450,7 +450,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
      */
     public function testFindByAssociationKey()
     {
-        list($userId, $addressId) = $this->loadAssociatedFixture();
+        [$userId, $addressId] = $this->loadAssociatedFixture();
         $repos = $this->_em->getRepository(CmsAddress::class);
         $addresses = $repos->findBy(['user' => $userId]);
 
@@ -464,7 +464,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
      */
     public function testFindAssociationByMagicCall()
     {
-        list($userId, $addressId) = $this->loadAssociatedFixture();
+        [$userId, $addressId] = $this->loadAssociatedFixture();
         $repos = $this->_em->getRepository(CmsAddress::class);
         $addresses = $repos->findByUser($userId);
 
@@ -478,7 +478,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
      */
     public function testFindOneAssociationByMagicCall()
     {
-        list($userId, $addressId) = $this->loadAssociatedFixture();
+        [$userId, $addressId] = $this->loadAssociatedFixture();
         $repos = $this->_em->getRepository(CmsAddress::class);
         $address = $repos->findOneByUser($userId);
 
@@ -856,7 +856,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
      */
     public function testMatchingCriteriaAssocationByObjectInMemory()
     {
-        list($userId, $addressId) = $this->loadAssociatedFixture();
+        [$userId, $addressId] = $this->loadAssociatedFixture();
 
         $user = $this->_em->find(CmsUser::class, $userId);
 
@@ -879,7 +879,7 @@ class EntityRepositoryTest extends OrmFunctionalTestCase
      */
     public function testMatchingCriteriaAssocationInWithArray()
     {
-        list($userId, $addressId) = $this->loadAssociatedFixture();
+        [$userId, $addressId] = $this->loadAssociatedFixture();
 
         $user = $this->_em->find(CmsUser::class, $userId);
 
